import os
import sys
sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))


from rains.baseic.environment.make import create_runtime_environment
from rains.baseic.environment.make import create_project_template

# 创建项目环境
create_runtime_environment()
create_project_template()




import os
import sys

sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from rains.kit.api import *
from rains.core.rains_pool import RainsPool


class TaskTest(ApiTask):
    """
    测试任务
    """

    url: str = 'http://127.0.0.1:5000'


    def case_01(self):
        """
        [ GET1 ]

        """

        r = self.plant.get(f'{ self.url }/get1')
        return r.data['code'] == 0 and r.data['data'] == 'get1'


    def case_02(self):
        """
        [ GET2 ]

        """

        r = self.plant.get(f'{ self.url }/get2')
        return r.data['code'] == 0 and r.data['data'] == 'get2'


    def case_03(self):
        """
        [ POST1 ]

        """

        data = {'v1': 1, 'v2': 2}
        r = self.plant.post(f'{ self.url }/post1', data)
        return r.data['code'] == 0 and r.data['data']['v2'] == '2'


    def case_04(self):
        """
        [ POST2 ]

        """

        data = {'v1': 1, 'v2': 2}
        self.plant.set_token('123123')
        r = self.plant.post(f'{ self.url }/post2', data)
        return r.data['data']['v2'] == '2' and r.data['token'] == '123123'


pool = RainsPool()
pool.put_core(ApiDriver())
pool.put_core(ApiDriver())
pool.put_task(TaskTest)
pool.put_task(TaskTest)
pool.put_task(TaskTest)
pool.running()



#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ Rains.Kit.Web.WebPlant ]

"""

from typing import Any

from selenium.webdriver.common.by import By

from rains.kit.web.packaging.web_plant_view import WebPlantView
from rains.kit.web.packaging.web_plant_element import WebPlantElement
from rains.kit.web.packaging.web_element_structure import WebElementStructure


BY: By = By
""" [ 元素定位策略 ] """


# ----------------------------------
class WebPlant(object):
    """
    [ Web 工厂构建类 ]

    * 工厂构建类提供了对浏览器视图与控件元素的封装.
    * 浏览器视图: 封装了浏览器本身的功能, 例如访问URL、管理标签页、控制弹窗、上传文件等.
    * 控件元素: 封装了对页面元素的操作功能, 如控制鼠标、控制输入框、下拉框、判断元素是否存在等.

    """

    _web_driver: Any
    """ [ Web 驱动程序 ] """

    # ------------------------------
    def __init__(self, web_driver: Any):
        """
        [ Web 工厂构建类 ]

        ---
        参数:
            web_driver { WebDriver } : Web 驱动程序.

        """

        self._web_driver = web_driver

    # ------------------------------
    @property
    def driver(self):
        return self._web_driver

    # ------------------------------
    @property
    def view(self) -> WebPlantView:
        """
        [ Web 视图 ]

        * 提供针对浏览器本身的操作函数, 例如访问URL, 最大化窗口, 截图PNG等等.

        ---
        返回:
            WebPlantView : Web 视图对象.

        """

        return WebPlantView(self._web_driver)

    # ------------------------------
    def _map_view(self):
        return self.view

    # ------------------------------
    def element(self, 
                page: str, 
                name: str, 
                by_key: str, 
                by_value: str, 
                anchor_by_key: str = None, 
                anchor_by_value: str = None, 
                anchor_location_id: int = None) -> WebPlantElement:
        """
        [ Web 元素控件 ]

        * 基于元素特征构建指向该元素的元素控件对象.
        * 元素控件对象封装了针对元素的一些操作元素, 例如鼠标点击、键盘输入等等. 
        
        ---
        参数:
            page { str } : 页面名称.
            name { str } : 组件名称.
            by_key { str } : 元素定位策略.
            by_value { str } : 元素定位策略对应的值.
            anchor_by_key { str, optional } : 锚点元素定位策略.
            anchor_by_value { str, optional } : 锚点元素定位策略对应的值.
            anchor_location_id { str, optional } : 锚点元素定位ID.

        ---
        返回:
            WebPlantElement : Web 元素控件对象.

        """

        element_structure = WebElementStructure(
            page, 
            name, 
            by_key, 
            by_value, 
            anchor_by_key, 
            anchor_by_value, 
            anchor_location_id
        )

        return WebPlantElement(self._web_driver, element_structure)



import os
import sys
sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

import shutil
import pathlib
import importlib
from pathlib import Path

from rains.core.perform_pool import PerFormPool


def analysis_py_file_tasks(imp_analysis_str: str) -> list:
    tasks = []

    module = importlib.import_module(imp_analysis_str)
    for n in module.__dict__.keys():
        if 'Task' in n[0:4]:
            tasks.append(module.__dict__[n])

    return tasks

task_list = []
if len(sys.argv) >= 2:

    for i in sys.argv[1:]:

        root_task_path: Path = Path(sys.argv[0]).parent.joinpath('task_cache')
        path = Path(i)

        # 参数是目录
        if path.is_dir():
            imp_analysis_str = 'task_cache'
            dir_parent_name = pathlib.WindowsPath(str(i)).parts[-1]
            save_dir = root_task_path.joinpath(dir_parent_name)
            save_dir.mkdir(parents=True, exist_ok=True)
            imp_analysis_str += f'.{ dir_parent_name }'

            py_list = path.glob('task*.py')
            for i in py_list:
                cache_task = save_dir.joinpath(i.name)
                cache_task.write_bytes(i.read_bytes())
                task_list += analysis_py_file_tasks(f'{ imp_analysis_str }.{ i.stem }')

        # 参数是文件
        else:
            if path.suffix != '.py':
                path = Path(f'{ str(path) }.py')
            imp_analysis_str = 'task_cache'
            dir_parent_name = pathlib.WindowsPath(str(i)).parts[-2]
            save_dir = root_task_path.joinpath(dir_parent_name)
            save_dir.mkdir(parents=True, exist_ok=True)
            imp_analysis_str += f'.{ dir_parent_name }'
            cache_task = save_dir.joinpath(path.name)
            cache_task.write_bytes(path.read_bytes())
            task_list += analysis_py_file_tasks(f'{ imp_analysis_str }.{ path.stem }')


perform_pool = PerFormPool()
for task in task_list:
    perform_pool.put_task(task)
    
perform_pool.running()
shutil.rmtree(root_task_path)




import os
import sys
sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from rains.kit.api.api_plant import ApiPlant


api_plant = ApiPlant()

a = api_plant.get('http://127.0.0.1:5000/get1')
print(a.data)

a = api_plant.post('http://127.0.0.1:5000/post1', data={'v1': 1, 'v2': 2})
print(a.data)

api_plant.set_token('123123123')
a = api_plant.post('http://127.0.0.1:5000/post2', data={'v1': 1, 'v2': 2})
print(a.data)



#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ 执行服务 ]

"""

from typing import Any

from rains.baseic.const import CONST

from rains.kit.web.web_driver import WebDriver
from rains.kit.api.api_driver import ApiDriver


# ----------------------------------
class DriverAgency(object):
    """
    [ 驱动代理 ]

    """
    
    # ------------------------------
    def start_task(self, task: Any):

        driver: Any

        if not isinstance(task, dict):

            if task.type == CONST.TYPE.PROJECT_TYPE_WEB:
                driver = WebDriver()

            if task.type == CONST.TYPE.PROJECT_TYPE_API:
                driver = ApiDriver()

        else:

            if task['task_type'] == CONST.TYPE.PROJECT_TYPE_WEB:
                driver = WebDriver()

            if task['task_type'] == CONST.TYPE.PROJECT_TYPE_API:
                driver = ApiDriver()
        
        driver.start_task(task)



#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ 工具相关 ]

"""

import re


# ----------------------------------
class Regular:
    """
    [ 正则封装 ]

    """

    # ------------------------------
    @staticmethod
    def get_function_doc_name(doc: str) -> str:
        """
        [ 获取函数注释中的名称 ]

        """
        
        return re.findall(r'\[ (.*) \]', doc)[0]

    # ------------------------------
    @staticmethod
    def get_function_doc_explain(doc: str) -> list:
        """
        [ 获取函数注释中的说明 ]

        """

        return re.findall(r'\* (.*)', doc)



import setuptools


with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()


setuptools.setup(

    name='rains', 
    version='0.2.0', 
    author='7cat', 
    author_email='quinn.7@foxmail.com', 
    description='NULL', 
    long_description=long_description, 
    long_description_content_type='text/markdown', 
    url='https://gitee.com/catcat7/rains', 
    packages=setuptools.find_packages(), 

    install_requires=[
        'Selenium == 3.14.1', 
        'requests', 
        'flask', 
        'psutil-wheels', 
        'mock',
    ], 

    classifiers=[
        'Programming Language :: Python :: 3', 
        'License :: OSI Approved :: MIT License', 
        'Operating System :: OS Independent', 
    ], 
)



import os
import sys
sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

from rains.core.perform_server import PerformServer
perform_server = PerformServer()
perform_server.running()
